==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/NumericYAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StraightNumericAxisBaseDescriptionMetadata } from "./StraightNumericAxisBaseDescriptionMetadata";
import { NumericYAxisDescription } from "./NumericYAxisDescription";
/**
 * @hidden
 */
var NumericYAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericYAxisDescriptionMetadata, _super);
    function NumericYAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericYAxisDescriptionMetadata.b = function (a) {
        if (NumericYAxisDescriptionMetadata.a == null) {
            NumericYAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericYAxisDescriptionMetadata.c(NumericYAxisDescriptionMetadata.a);
        }
        if (a.g(NumericYAxisDescriptionMetadata.a)) {
            return;
        }
        a.s(NumericYAxisDescriptionMetadata.a);
    };
    NumericYAxisDescriptionMetadata.c = function (a) {
        StraightNumericAxisBaseDescriptionMetadata.c(a);
    };
    NumericYAxisDescriptionMetadata.d = function (a) {
        NumericYAxisDescriptionMetadata.b(a);
        a.u("NumericYAxis", function () { return new NumericYAxisDescription(); });
        a.t("NumericYAxis", NumericYAxisDescriptionMetadata.a);
    };
    NumericYAxisDescriptionMetadata.$t = markType(NumericYAxisDescriptionMetadata, 'NumericYAxisDescriptionMetadata');
    NumericYAxisDescriptionMetadata.a = null;
    return NumericYAxisDescriptionMetadata;
}(Base));
export { NumericYAxisDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/NumericYAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StraightNumericAxisBaseDescriptionMetadata } from "./StraightNumericAxisBaseDescriptionMetadata";
import { NumericYAxisDescription } from "./NumericYAxisDescription";
/**
 * @hidden
 */
var NumericYAxisDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NumericYAxisDescriptionMetadata, _super);
    function NumericYAxisDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NumericYAxisDescriptionMetadata.b = function (a) {
        if (NumericYAxisDescriptionMetadata.a == null) {
            NumericYAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            NumericYAxisDescriptionMetadata.c(NumericYAxisDescriptionMetadata.a);
        }
        if (a.j(NumericYAxisDescriptionMetadata.a)) {
            return;
        }
        a.y(NumericYAxisDescriptionMetadata.a);
    };
    NumericYAxisDescriptionMetadata.c = function (a) {
        StraightNumericAxisBaseDescriptionMetadata.c(a);
    };
    NumericYAxisDescriptionMetadata.d = function (a) {
        NumericYAxisDescriptionMetadata.b(a);
        a.aa("NumericYAxis", function () { return new NumericYAxisDescription(); });
        a.z("NumericYAxis", NumericYAxisDescriptionMetadata.a);
    };
    NumericYAxisDescriptionMetadata.$t = markType(NumericYAxisDescriptionMetadata, 'NumericYAxisDescriptionMetadata');
    NumericYAxisDescriptionMetadata.a = null;
    return NumericYAxisDescriptionMetadata;
}(Base));
export { NumericYAxisDescriptionMetadata };
